function out = pressuretab(T)

%% converting from PSI to Pa & from ft to m in the tables
for i = 1:length(T.formation.depth)
    poretabSI(i) = T.formation.sgpore(i)/T.conv.psibar*1e5; % from psi (indata) to bar, and then to Pa
    fractabSI(i) = T.formation.sgfrac(i)/T.conv.psibar*1e5;
    depthtabSI(i) = T.formation.depth(i)/T.conv.ftm; % from ft to m.
end

%% Making extrapolations between the points in the curves read from the excelsheet

% The pore pressure curves are extrapolated
k=1;
for i = 2:length(depthtabSI)
    deltaD = depthtabSI(i) - depthtabSI(i-1);
    deltaP = poretabSI(i) - poretabSI(i-1);
    dPdD = deltaP/deltaD;                               % stigningstall i trykk/dybde
    for j = ceil(depthtabSI(i-1)):ceil(depthtabSI(i))
        sgporetab(k) = poretabSI(i-1) + (j-ceil(depthtabSI(i-1)))*dPdD;
        k = k + 1;
    end
end

% The fracture curve is extrapolated
k=1;
for i = 2:length(depthtabSI)
    deltaD = depthtabSI(i) - depthtabSI(i-1);
    deltaP = fractabSI(i) - fractabSI(i-1);
    dPdD = deltaP/deltaD;                               % stigningstall i trykk/dybde
    for j = ceil(depthtabSI(i-1)):ceil(depthtabSI(i))
        depth(k) = j;
        sgfractab(k) = fractabSI(i-1) + (j-ceil(depthtabSI(i-1)))*dPdD;
        k = k + 1;
    end
end

%% adding the defined SafetyMargins and creating other tables. in SI-units
for i = 1:length(depth)
    out.pptab(i) = sgporetab(i);
    out.fptab(i) = sgfractab(i);
    out.ppmargintab(i) = sgporetab(i) + T.formation.km*T.misc.g*depth(i);
    out.fpmargintab(i) = sgfractab(i) - T.formation.fm*T.misc.g*depth(i);

    out.mwtab(i) = out.fptab(i)-out.pptab(i);
    out.mwmargintab(i) = out.fpmargintab(i) - out.ppmargintab(i);
end

%% making the Pressure curve
for i = 1:(length(depth) + depth(1))
    depthrkb(i) = i;

    if i < T.tally.dual.depthmaxfi
        out.Pmud(i) = T.fluid.rho1*T.misc.g*depthrkb(i);
    else
        out.Pmud(i) = (T.fluid.rho1*T.misc.g*T.tally.dual.depthmaxfi + T.fluid.rho2*T.misc.g*(depthrkb(i)-T.tally.dual.depthmaxfi));
    end
    out.wp(i) = T.fluid.rhow*depthrkb(i)*T.misc.g; %creating a table with the water pressure. 

end

%% Converting the tables to depthmarks related to the RKB, instead of seabottom.
for i = 1:length(out.ppmargintab) % this loop saves the data from the 
    temptabmpp(i) = out.ppmargintab(i); % saving the values that goes from seabed and downwards
    temptabmfp(i) = out.fpmargintab(i);

    temptabpp(i) = out.pptab(i);  % saving 
    temptabfp(i) = out.fptab(i);
    
    out.fptab(i) = 0;
    out.pptab(i) = 0;
    out.ppmargintab(i) = 0;
	out.fpmargintab(i) = 0;
    out.mwmargintab(i) = 0;
    out.mwtab(i) = 0;
end
for i = (depth(1)+1):length(depthrkb)
    out.ppmargintab(i) = temptabmpp(i-depth(1));
    out.fpmargintab(i) = temptabmfp(i-depth(1));
    out.mwmargintab(i) = out.fpmargintab(i) - out.ppmargintab(i);
    
    out.fptab(i) = temptabfp(i-depth(1));
    out.pptab(i) = temptabpp(i-depth(1));
    out.mwtab(i) = out.fptab(i) - out.pptab(i);
    
end

%% Plotting the results
x = 1;
if x == 0;  % setter p denne bare for  unng at den plotter grafen ved hver gjennomkjring. 
figure;
plot(out.ppmargintab/1e5,depthrkb,'-r',out.fpmargintab/1e5,depthrkb,'-g', out.wp/1e5,depthrkb,'-b',out.Pmud/1e5,depthrkb,'-.b' );
title('Pressure curves WITH added SafetyMargins','FontSize',12,'FontWeight','bold');
xlabel('Pressure [bar]','FontWeight','bold');
ylabel('Depth [m]','FontWeight','bold');
set(gca,'YDir','reverse');
hleg2 = legend('PoreP-margin','FracP-margin','P,water','Pressure in the mud');
set(hleg2,'Location','NorthEast');
axis([-50, 1000, -50, 6000]);
line([0,1000],[(T.tally.dual.depthmaxfi),(T.tally.dual.depthmaxfi)]); % putting in a line in the plot for the maximum depth of the Fluid interface
line([0,1000],[(T.tally.dual.casingdepth),(T.tally.dual.casingdepth)]); 

figure;
plot(out.pptab/1e5,depthrkb,'-r',out.fptab/1e5,depthrkb,'-g', out.wp/1e5,depthrkb,'-b');%,out.Pmud/1e5,depthrkb,'-.b' );
title('Formation Pressure curves','FontSize',12,'FontWeight','bold');
xlabel('Pressure [bar]','FontWeight','bold');
ylabel('Depth [m]','FontWeight','bold');
set(gca,'YDir','reverse');
hleg2 = legend('PoreP','FracP','P,water');%,'Pressure in the mud');
set(hleg2,'Location','NorthEast');
axis([-50, 1000, -50, 6000]);
line([0,1000],[T.tally.dual.depthmaxfi, T.tally.dual.depthmaxfi],'Color','k','Linestyle','-.'); % putting in a line in the plot for the maximum depth of the Fluid interface
line([0,1000],[T.tally.scd, T.tally.scd],'Color','k','Linestyle','-.'); % line for surface casing setting depth
% line([0,1100],[(T.tally.dual.casingdepth),(T.tally.dual.casingdepth)]);
grid on;

figure;
plot(out.mwmargintab/1e5,depthrkb, out.mwtab/1e5,depthrkb);
title('Mud Window. W/WO margins.');
set(gca,'YDir','reverse');
hleg2 = legend('MW w/ Margins','MW wo/ Margins');
set(hleg2,'Location','NorthEast');

end
end