function pumpstop(w,x)

%% Setting start parameters
Vinflux = 0;
Voutflux = 0;
tvd = w.tally.dual.casingdepth + 20;
dPfriction = w.ptrap.dpfriction/w.conv.psibar*1e5;

BHPstart = x.ppmargintab(tvd) + w.formation.circmargin*1e5; % setting the wanted bhp for optimal ROP

dfi = (BHPstart - dPfriction - tvd*w.fluid.rho2*w.misc.g)/((w.fluid.rho1-w.fluid.rho2)*w.misc.g);
disp([' her er dfi ',num2str(dfi)]);

qbp = w.pumps.qbpmin;

tlatency = w.pumps.timedelay; % setting a delay before the pumps starts

%% calculating other parameters
csohbha = pi/4*(w.tally.dopenhole^2 - w.tally.odbha^2);                     % cross section area between the open hole and the BHA.
csohdp = pi/4*(w.tally.dopenhole^2 - w.tally.ddrillpipe^2);                 % cross section area between the open hole and drillpipe

csriserannulus = pi/4*(w.tally.idriser^2-w.tally.ddrillpipe^2)             % cross section area between the riser and the drill pipe
csandp = pi/4*(w.tally.dual.idcasing^2 - w.tally.ddrillpipe^2)             % cross section area between casing and drill pipe.
cscasbha = pi/4*(w.tally.dual.idcasing^2 - w.tally.odbha^2);                % cross section area between casing and BHA

csareadp = w.tally.ddrillpipe^2*pi/4;                                       % cross section area of the drill pipe
csopenhole = pi/4*w.tally.dopenhole^2;                                      % cross section area of the open hole

% Volume of the heavy mud at the start of the process.
Vheavymudstart = (tvd - w.tally.dual.casingdepth)*csohbha + (w.tally.lbha-(tvd-w.tally.dual.casingdepth))*cscasbha... 
    + (tvd - w.tally.lbha-w.tally.conv.lriser)*csandp + (w.tally.conv.lriser - dfi)*csriserannulus;

Vwellbore = Vheavymudstart + dfi*csriserannulus;

t = 0;
% showing circulation for the first 30 seconds.
for i = 1:30
    t = t + 1;

    qrp = w.pumps.qrpmax;
    qbp = w.pumps.qbpmin;
    qsp = min(qrp + qbp , w.pumps.qspmax);
    BHP = (dfi*w.fluid.rho1*w.misc.g + (tvd-dfi)*w.fluid.rho2*w.misc.g) + dPfriction;

    qrptab(t) = qrp;
    qbptab(t) = qbp;
    qsptab(t) = qsp;
    ttab(t) = t;
    dfitab(t) = dfi;
    BHPtab(t) = BHP;
    dVformflux(t) = formationflow(w,x,BHP,tvd);
end
tmid = t;

qrp = 0; % Rig pump is turned off
BHP = BHPstart - dPfriction; %Mud pressure looses the friction pressure

while BHP < BHPstart
    t = t+1;
    % disp(['Tiden er: ',num2str(t)]);

    dVformflux(t) = formationflow(w,x,BHP,tvd); % the calculated influx volume at the current mud pressure
    
    if dVformflux(t) > 0
        Vinflux = Vinflux + dVformflux(t);
    elseif dVformflux(t) < 0
        Voutflux = Voutflux + dVformflux(t)
        return
    end
    
	netVformation = Vinflux + Voutflux;
%     disp([' Net formation er : ',num2str(netVformation)]);
    
    %% Calculating the height of the formation fluid influx
    hinflux = netVformation/csohbha;
    if hinflux > tvd - w.tally.dual.casingdepth;
        usedV = (tvd - w.tally.dual.casingdepth)*csohbha;
        hinflux =  (tvd - w.tally.dual.casingdepth) + (netVformation-usedV)/cscasbha;
    end
    if hinflux > w.tally.lbha
        usedV = (tvd - w.tally.dual.casingdepth)*csohbha + (w.tally.lbha-(tvd-w.tally.dual.casingdepth))*cscasbha;
        hinflux = w.tally.lbha + (netVformation-usedV)/csandp;
    end
    if hinflux > (tvd - w.tally.conv.lriser)
        usedV = (tvd - w.tally.dual.casingdepth)*csohbha + (w.tally.lbha-(tvd-w.tally.dual.casingdepth))*cscasbha +...
            (tvd - w.tally.lbha-w.tally.conv.lriser)*csandp;
        hinflux = (tvd - w.tally.conv.lriser) + (netVformation-usedV)/csriserannulus;
    end

    %% 
%     disp([' hyden p influx er  : ',num2str(hinflux)]);
    ddfi = dVformflux(t)/csriserannulus; %change in fluid interface depth due to the influx at the casing shoe
    dfi = dfi - ddfi; % the new depth of the fluid interface
    
    BHP = dfi*w.fluid.rho1*w.misc.g + (tvd-dfi-hinflux)*w.fluid.rho2*w.misc.g + w.fluid.formfluid*w.misc.g*hinflux;
    
    if BHPstart > BHP % If the current pressure is too low
        %regn ut ndvendig volum, og deretter ndvendig rate.
        reqdfi = (BHPstart-BHP)/((w.fluid.rho2-w.fluid.rho1)*w.misc.g);
%         disp([' requried change in fluid interface is ',num2str(reqdfi)]);
        reqV = csriserannulus * reqdfi;
        qbp = min((reqV*6e4+w.pumps.qspmin),w.pumps.qbpmax);
        qsp = w.pumps.qspmin;
    elseif BHPstart < BHP
        reqdfi = (BHP-BHPstart)/((w.fluid.rho2-w.fluid.rho1)*w.misc.g);
        reqV = csriserannulus*reqdfi;
        qsp = min((reqV*6e4) + w.pumps.qbpmin,w.pumps.qspmax);
        qbp = w.pumps.qbpmin;
    end
    
    if t <= (tmid + w.pumps.timedelay) % delay in time from the point where the rig pump loses power, to when the subseapump is turned on
        qbp = w.pumps.qbpmin;
        qsp = w.pumps.qspmin;
%          disp([' tiden er her: ',num2str(t)]);
    end
    
	ddfi = ( qbp/6e4 - qsp/6e4 )/csriserannulus;
    dfi = dfi - ddfi;

     BHP = dfi*w.fluid.rho1*w.misc.g + (tvd-dfi-hinflux)*w.fluid.rho2*w.misc.g + w.fluid.formfluid*w.misc.g*hinflux;
%      disp([' Pshoe er her: ',num2str(Pshoe/1e5)]);
    
    dfitab(t) = dfi;
    BHPtab(t) = BHP;
    qrptab(t) = qrp;
    qbptab(t) = qbp;
    qsptab(t) = qsp;
    ttab(t) = t;
    

    if hinflux > (tvd - w.tally.dual.spinlet) || dfi < 50 % setting criteria for when the well is considered uncontrolled.
        BHP = BHPstart *1.01;
    end
    
    
end
a = hinflux
for i = t+1:(round(t*1.1))
    dfitab(i) = dfi;
    BHPtab(i) = dfi*w.fluid.rho1*w.misc.g + (tvd-dfi-hinflux)*w.fluid.rho2*w.misc.g + w.fluid.formfluid*w.misc.g*hinflux;
    qrptab(i) = 0;
    qsptab(i) = w.pumps.qspmin;
    qbptab(i) = w.pumps.qspmin;
    ttab(i) = i;
    dVformflux(i) = formationflow(w,x,BHP,tvd);
end

%% finding the new composition. 

%% Plotting the pump rates
p = 1;
if p == 1
figure;
plot(ttab/60,qbptab,ttab/60,qsptab,ttab/60,qrptab);

title('Pump rates','FontWeight','Bold','FontSize',14);
xlabel('Time [min]','FontWeight','Bold','FontSize',14);
ylabel('Pump rates [LPM]','FontWeight','Bold','FontSize',14);

legend('Booster pump','Subsea pump','Rig pump')
axis([-length(ttab)/60*0.05, t/60*1.1, 0 ,max([max(qsptab),max(qbptab), max(qrptab) ])*1.1]);

%% Plotting the Pressure graph at the shoe. 
figure;
plot(ttab/60, BHPtab/1e5,'-b');
axis([0, t/60*1.1,  ( min(BHPtab)*0.98 )/1e5,  x.fptab(tvd)*1.01/1e5 ]);
title('BHP-Hydrostatic; Pressure Margins included','FontWeight','Bold','FontSize',14);

fpmline = [x.fpmargintab(tvd),x.fpmargintab(tvd)];
ppmline = [x.ppmargintab(tvd),x.ppmargintab(tvd)];
fpline = [x.fptab(tvd),x.fptab(tvd)];
ppline = [x.pptab(tvd),x.pptab(tvd)];
pmudline = [ BHPstart, BHPstart];

line([-1,t],fpline/1e5,'Color','k');
line([-1,t],fpmline/1e5,'Color','k','Line','--');
line([-1,t],ppmline/1e5,'Color','r','Line','--');
line([-1,t],ppline/1e5,'Color','r');
line([-1,t],pmudline/1e5,'Color','y');

hleg2 = legend('P-mud-hyd','P-fracture','P-fracture,m','P-pore,m','P-pore','P-mud@start');
set(hleg2,'Location','NorthWest');
xlabel('Time [min]','FontWeight','Bold','FontSize',14);
ylabel('Pressure [bar]','FontWeight','Bold','FontSize',14);

%% Plotting the depth of the fluid interface
figure;
plot(ttab/60,dfitab);
title(' Position of fluid interface','FontWeight','Bold','FontSize',14);
ylabel('Depth [mTVD]','FontWeight','Bold','FontSize',14);
xlabel('Time [min]','FontWeight','Bold','FontSize',14);

set(gca,'YDir','reverse');
% Pshoe = (dfi*w.fluid.rho1*w.misc.g + (tvd-dfi)*newrho*w.misc.g);

%% Plotting the depth of the fluid interface
figure;
bar(ttab/60,dVformflux*1000);
title(' Formation fluid Influx into the wellbore (Bar diagram)','FontWeight','Bold','FontSize',14);
ylabel('Fluid Flow [L]','FontWeight','Bold','FontSize',14);
xlabel('Time [min]','FontWeight','Bold','FontSize',14);
influx = ['Total formation influx volume: ',num2str(Vinflux*1000),' L'];
outflux = ['Total mud volume lost to the formation: ',num2str(Voutflux*1000),' L'];

% text1 = ['Influx volume in percent of original mud volume: ',num2str(100*netVformation/Vanaboveshoe),' %'];
% text2 = ['Theoretical new density d.t. influx: ',num2str(newrho),'kg/m3'];
% text3 = ['Theoretical change in Phyd at Shoe: ',num2str(dPshoe/1e5),' bar'];
% text4 = ['Assumed formation fluid density: ',num2str(w.fluid.formfluid),' kg/m3'];
%  text(0.3*length(ttab)/60,0.75*max(dVformflux*1000),{influx;outflux}); %;' ';text1;text2;text3});
end

if hinflux > (tvd - w.tally.dual.spinlet) || dfi < 50
    ok = 0;
    disp(' FAILURE!');
else
    ok = 1;
    disp(' SUCCESSS!!');
end

results = [t/60; w.pumps.timedelay; 0;...
    Vinflux*1000; Vinflux/Vwellbore; hinflux; dfi; 0;...
    w.tally.idriser*12*w.conv.ftm; w.tally.ddrillpipe*12*w.conv.ftm; w.tally.odbha*12*w.conv.ftm; w.tally.lbha; tvd; 0;...
    dPfriction/1e5; w.formation.circmargin; w.fluid.rho1; w.fluid.rho2; w.fluid.formfluid; 0;...
    w.pumps.qbpmax; w.pumps.qspmin; w.pumps.qbpmin; 0;...
    ok];

xlswrite('Results.xlsx',results);

p = 0;
if p == 1
%% Finding a Polynomial that fits the calculated values

for i = 30:(length(ttab)-round(t*0.1)-1)
    polyttab(i-29) = ttab(i);    % puts values of interest for polynomial calculation into a table
    polybhptab(i-29) = BHPtab(i);
end

grad = 2;   %selects the grade of polynomial
p = polyfit(polyttab,polybhptab,grad)  % uses the integrated matlab function polyfit for the regression
format long, p;     % increase the format of the found coefficients for increased accuracy
format long, konstledd  = p(grad+1);    % defines the found coefficients from the regression
format long, forste     = p(grad);
format long, andre      = p(grad-1);
% format long, tredje     = p(grad-2);
% % format long, fjerde     = p(grad-3);
testt = tlatency*1.2;

for testt = 1:length(polybhptab)
    testvaluetab(testt) = konstledd + forste*testt + andre*testt^2;% + tredje*testt^3;% + fjerde*testt^4;
end

figure;
plot(testvaluetab/1e5);

disp([' The BHP at the end of time is: ',num2str(testvaluetab(length(testvaluetab))/1e5)]);

% if tredje < 1e-4    % Neglecting the third-degree-part of the equation if it is too small (the higher-degree-parts will be even smaller)
%     polytxt = ['Qrp [LPM] = ',num2str(andre),'*t^2 ',num2str(forste),'*t + ', num2str(konstledd)];  % creates a text string with the found function
% else
%     polytxt = ['Qrp [LPM] = ',num2str(tredje),'*t^3 + ',num2str(andre),'*t^2 ',num2str(forste),'*t + ', num2str(konstledd)];
% end
% disp(polytxt);
% sone = [num2str(1),' < t [s] < ',num2str(length(ttab)-1),];
end
end