
% this program will simulate the process of making a connection when drilling
% The BHP is to be held constant, while the Pump rates are changed.
% 
% Input data is the Excel-sheet with the indata

function out = read_data(file)

%% Read FLUID PROPERTIES and put into variable out
[num text raw] = xlsread(file,'fluid');

out.fluid.rho2   = num(1,1); % read values for density of heavy fluid
out.fluid.rho1   = num(2,1); % read values for density of light fluid
out.fluid.n     = num(5,1); % read value of n in [-]
out.fluid.K     = num(6,1); % read value of K in Pa

out.fluid.ypl.ty = num(17,1);
out.fluid.ypl.n = num(18,1);
out.fluid.ypl.K = num(19,1);

out.fluid.rhow  = num(30,1);
out.fluid.formfluid = num(31,1);

out.ptrap.dpfriction = num(33,1);
out.ptrap.dfriction = num(34,1);

%% Read HOLE segments, lengths and diameters

[num text raw] = xlsread(file,'tally_conventional');

%common parameters: diameters of the pipelines
out.tally.idriser = num(9,2);
out.tally.dopenhole = num(37,2);
out.tally.ddrillpipe = num(42,2);
out.tally.totalvd = num(2,1);
out.tally.odbha = num(45,2);
out.tally.lbha = num(46,1);
out.tally.lstand = num(48,1);
out.tally.seafloor = num(1,1);
out.tally.scd = num(51,1);

% Read parameters for the conventional case; when drilling the last section
% of the 8 1/2" open hole, before running liner. 
out.tally.conv.lriser = num(1,1);
out.tally.conv.lcasing(1) = num(16,1) - num(15,1);
out.tally.conv.lcasing(2) = num(22,1) - num(21,1);
out.tally.conv.lcasing(3) = num(28,1) - num(27,1);
out.tally.conv.lcasing(4) = num(34,1) - num(33,1);
out.tally.conv.lopenhole = num(39,1) - num(38,1);

out.tally.conv.idcasing(1) = num(14,2);
out.tally.conv.idcasing(2) = num(20,2);
out.tally.conv.idcasing(3) = num(26,2);
out.tally.conv.idcasing(4) = num(32,2);

%% Read Hole segment, length and diameters for a DualGradient Case of drilling
[num text raw] = xlsread(file,'tally_dualgrad');

out.tally.dual.spinlet = num(8,1);
out.tally.dual.depthmaxfi = num(10,1);
out.tally.dual.casingdepth = num(33,1);
out.tally.dual.idcasing = num(31,2);

%% Read formation properties

[num text raw] = xlsread(file,'formation');

k = length(num);
start = 8;

for i = start:k
out.formation.depth(i-(start-1)) = num(i,1);    % leser inn dybde i fot
out.formation.sgpore(i-(start-1)) = num(i,3);   % reading the porepressure gradient in PSI
out.formation.sgfrac(i-(start-1)) = num(i,4);   % reading the LOT/FIT-pressure gradient in PSI
end

out.formation.km = num(1,2);
out.formation.fm = num(2,2);
out.formation.bhpm = num(3,2);
out.formation.phydmargin = num(4,2);
out.formation.circmargin = num(5,2);

%% Read misc data

[num text raw] = xlsread(file,'misc');
out.misc.g = num(1,1);
out.conv.dens = num(4,1);
out.conv.ftm = num(5,1);    %conversion factor from foot to meter
out.misc.turb = num(6,1);
out.conv.psibar = num(8,1);


%% Read pump data

[num text raw] = xlsread(file,'pumps');

out.pumps.qrpstart = num(1,1);
out.pumps.qspstart = num(1,1);
out.pumps.qrpmax = num(2,1);

out.pumps.qbpmax = num(1,7);
out.pumps.qbpmin = num(2,7);

out.pumps.qspmin = num(2,4);
out.pumps.qspmax = num(3,4);

out.pumps.timedelay = num(5,1);

%% Read Surge and Swab data

[num text raw] = xlsread(file,'surgeswab');

out.misc.pi = num(11,2);

out.tripping.amax = num(4,2);
out.tripping.vmax = num(5,2);

yplline = 18;
out.tripping.A = num(yplline,2);
out.tripping.B = num(yplline,3);
out.tripping.C = num(yplline,4);
out.tripping.D = num(yplline,5);
out.tripping.E = num(yplline,6);
out.tripping.F = num(yplline,7);

out.tripping.acf = num(7,2);

end